@@ -9,7 +9,7 @@ __author__ = 'IncognitoCoding'
 __copyright__ = 'Copyright 2022, type_check'
 __credits__ = ['IncognitoCoding']
 __license__ = 'MIT'
-__version__ = '0.0.7'
+__version__ = '0.0.8'
 __maintainer__ = 'IncognitoCoding'
 __status__ = 'Beta'
 
@@ -21,6 +21,10 @@ def type_check(value: any, required_type: Union[type, list],
 
     Raises a cleanly formatted reason if the type validation is unsuccessful.
 
+    None value will return different exceptions based on msg_override.\\
+    \t\\- No msg_override = FAttributeError\\
+    \t\\- msg_override = FTypeError
+
     No return output.
 
     Args:
@@ -43,6 +47,8 @@ def type_check(value: any, required_type: Union[type, list],
     Raises:
         FAttributeError (fexception):
         \t\\- The value \'{value}\' sent is not an accepted input.
+        FTypeError (fexception):
+        \t\\- A user defined msg_override message.
         FAttributeError (fexception):
         \t\\- No type or list of types has been entered for type validation.
         FTypeError (fexception):
@@ -53,14 +59,25 @@ def type_check(value: any, required_type: Union[type, list],
         value is None
         or value == ''
     ):
-        exc_args: dict = {
-            'main_message': f'The value \'{value}\' sent is not an accepted input.',
-            'expected_result': 'Any value other than None or an empty string',
-            'returned_result': type(value)
-        }
-        if not tb_remove_name:
-            tb_remove_name = 'type_check'
-        raise FAttributeError(message_args=exc_args, tb_limit=None, tb_remove_name=tb_remove_name)
+        # Sets message override if one is provided.
+        if msg_override:
+            exc_args: dict = {
+                'main_message': msg_override,
+                'expected_result': 'Any value other than None or an empty string',
+                'returned_result': type(value)
+            }
+            if not tb_remove_name:
+                tb_remove_name = 'type_check'
+            raise FTypeError(message_args=exc_args, tb_limit=None, tb_remove_name=tb_remove_name)
+        else:
+            exc_args: dict = {
+                'main_message': f'The value \'{value}\' sent is not an accepted input.',
+                'expected_result': 'Any value other than None or an empty string',
+                'returned_result': type(value)
+            }
+            if not tb_remove_name:
+                tb_remove_name = 'type_check'
+            raise FAttributeError(message_args=exc_args, tb_limit=None, tb_remove_name=tb_remove_name)
 
     # Verifies a type or list is sent.
     if (
